@@ -246,9 +246,15 @@ class TableHelper:
 
         # Lists / tuples => IN / NOT IN
         if isinstance(val, (list, tuple)) and "><" not in key:
+            # Convert to tuple for better PostgreSQL parameter handling
+            val_tuple = tuple(val)
+            # Use IN/NOT IN instead of ANY for better type compatibility
             if "!" in key:
-                return f"{column} != ANY(%s)", list(val)
-            return f"{column} = ANY(%s)", list(val)
+                placeholders = ",".join(["%s"] * len(val_tuple))
+                return f"{column} NOT IN ({placeholders})", val_tuple
+            else:
+                placeholders = ",".join(["%s"] * len(val_tuple))
+                return f"{column} IN ({placeholders})", val_tuple
 
         # "@@" => pass as literal
         if isinstance(val, str) and val.startswith("@@") and val[2:]:
